@@ -308,21 +308,30 @@ bool FileSystemSyncServer::commit_sync_transaction()
       xml->close();
       Glib::ustring xml_content = xml->to_string();
       delete xml;
-      auto stream = manifest_file->create_file(Gio::FILE_CREATE_REPLACE_DESTINATION);
+      xml = nullptr;
+      if(manifest_file->query_exists()) {
+        manifest_file->remove();
+      }
+      auto stream = manifest_file->create_file();
       stream->write(xml_content);
       stream->close();
     }
     catch(...) {
-      xml->close();
-      delete xml;
+      if(xml) {
+        xml->close();
+        delete xml;
+      }
       throw;
     }
 
 
     // Rename original /manifest.xml to /manifest.xml.old
     Glib::RefPtr<Gio::File> oldManifestPath = Gio::File::create_for_uri(m_manifest_path->get_uri() + ".old");
+    if(oldManifestPath->query_exists()) {
+      oldManifestPath->remove();
+    }
     if(m_manifest_path->query_exists() == true) {
-      m_manifest_path->move(oldManifestPath, Gio::FILE_COPY_OVERWRITE);
+      m_manifest_path->move(oldManifestPath);
     }
 
     // * * * Begin Cleanup Code * * *
